/**
 * BLOCK: gosign-notification-and-alert-block
 *
 * Registering a basic block with Gutenberg.
 * Simple block, renders and saves the same content without any interactivity.
 */

import classnames from "classnames";
import MaterialUiIconPicker from 'react-material-ui-icon-picker';


//  Import CSS.
import './style.scss';
import './editor.scss';

const { __ } = wp.i18n; // Import __() from wp.i18n
const { registerBlockType } = wp.blocks; // Import registerBlockType() from wp.blocks
const { Component, Fragment } = wp.element;
const { PanelBody, RangeControl, SelectControl, Toolbar, TextControl } = wp.components;
const {
	InspectorControls,
	PanelColorSettings,
	BlockControls,
	RichText,
	InnerBlocks,
	TabPanel,
	AlignmentToolbar
} = wp.editor;

/**
 * Register: aa Gutenberg Block.
 *
 * Registers a new block provided a unique name and an object defining its
 * behavior. Once registered, the block is made editor as an option to any
 * editor interface where blocks are implemented.
 *
 * @link https://wordpress.org/gutenberg/handbook/block-api/
 * @param  {string}   name     Block name.
 * @param  {Object}   settings Block settings.
 * @return {?WPBlock}          The block, if it has been successfully
 *                             registered; otherwise `undefined`.
 */
registerBlockType( 'cgb/block-gosign-notification-and-alert-block', {
	// Block name. Block names must be string that contains a namespace prefix. Example: my-plugin/my-custom-block.
	title: __( 'Gosign Notification And Alert Block' ), // Block title.
	icon: {
		// Specifying a color for the icon (optional: if not set, a readable color will be automatically defined)
		foreground: '#ff6f00',
		// Specifying a dashicon for the block
		src: 'warning',
	}, // Block icon from Dashicons → https://developer.wordpress.org/resource/dashicons/.
	category: 'common', // Block category — Group blocks together based on common traits E.g. common, formatting, layout widgets, embed.
	keywords: [
		__( 'gosign notification and alert block' ),
		__( 'CGB Example' ),
		__( 'create-guten-block' ),
	],

	attributes: {
		text: {
			type: 'string'
		},
		textcolor: {
			type: 'string',
			default: '#000000'
		},
		buttontext: {
			type: 'string',
			default: ' Add note here from panel'
		},
		buttoncolor: {
			type: 'string',
			default: '#cadaa3'
		},
		buttontextcolor: {
			type: 'string',
			default: '#000000'
		},
		boxcolor: {
			type: 'string',
			default: '#E0F1B5'
		},
		align: {
			type: 'string',
			default: 'center'
		},
		customSizeIcon: {
			default: 18,
			type: 'int'
		},
		iconColorCus: {
			type: 'string',
			default: '#000000'
		},
		iconName: {
			type: 'string',
			default: ''
		},
		iconCode: {
			type: 'string',
			default: ''
		},
		customWidth: {
			default: 100,
			type: 'number'
		},
		shortSep: {
			type: 'string',
			default: 'center'
		},
		mediaID: {
			type: 'int'
		}
	},

	/**
	 * The edit function describes the structure of your block in the context of the editor.
	 * This represents what the editor will render when the block is used.
	 *
	 * The "edit" property must be a valid function.
	 *
	 * @link https://wordpress.org/gutenberg/handbook/block-api/block-edit-save/
	 */
	edit: function( props ) {
		const { attributes, setAttributes } = props;
		const {
			text,
			textcolor,
			buttontext,
			buttoncolor,
			buttontextcolor,
			boxcolor,
			align,
			customSizeIcon,
			iconColorCus,
			iconName,
			iconCode,
			mediaID,
			shortSep,
			customWidth
		} = attributes;

		const onSelect = ( tabName ) => {};


		const onSelect2 = ( tabName2 ) => {
			props.setAttributes({
				mediaURL: "",
				mediaID: ""
			})
		};
		function onIconSelect(media) {
			props.setAttributes({
				mediaURL: media.url,
				mediaID: media.id,
			});
			emptymedia2();
		}
		function showPickedIcons(icon) {
			props.setAttributes({
				iconName: icon.name,
				iconCode: icon.code,
			});
			emptyIcon();
		}

		function emptyIcon(){
			setAttributes({mediaURL:"",mediaID:""});
		}
		function emptymedia2(){
			setAttributes({iconName:"",iconCode:""});
		}
		// Creates a <p class='wp-block-cgb-block-gosign-notification-and-alert-block'></p>.
		return (
			<Fragment>
				<div className={classnames('notification-block', {[`pos-${shortSep}`]: true} )}>
					<div className="editor-noteBlock"   style={{ backgroundColor: boxcolor, width:customWidth+"%"}}>
						{buttontext && (
							<div className="gosign-alertbox-button">
								<p style={{ backgroundColor: buttoncolor, color:buttontextcolor}}>{buttontext}</p>
							</div>
						)}
						<div className="gosign-alertbox-textbox" style={{ textAlign: align, color: textcolor }}>
							<RichText
								tagName="p"
								className={props.className}
								value={text}
								placeholder={__('Add your text here')}
								// formattingControls={[]}
								onChange={function(text) {
								setAttributes({ text: text });
							  }}
							/>
						</div>
					</div>
					<div className="clear"></div>
				</div>
				<InspectorControls>

					<TextControl
						label="Note Text"
						value={ buttontext }
						onChange={function(buttontext) {
							setAttributes({ buttontext: buttontext });
						}}
					/>

					<RangeControl
						label={__('Enter width in %')}
						value={customWidth}
						min='10'
						max='100'
						step='1'
						onChange={function( customWidth ) {
							props.setAttributes( { customWidth: customWidth } );
						}}
					/>
					<SelectControl
						label="Position"
						value={shortSep}
						options={[
							{ label: "Center", value: "center" },
							{ label: "Left", value: "left" },
							{ label: "Right", value: "right" }
						]}
						onChange={shortSep => {
							setAttributes({ shortSep });
						}}
					/>
					<PanelColorSettings
						title={__("Note Color Settings")}
						initialOpen={false}
						colorSettings={[
						{
						  value: buttoncolor,
						  onChange: buttoncolor =>
							props.setAttributes({ buttoncolor: buttoncolor }),
						  label: __("Note Background Color")
					  	},
						{
						  value: buttontextcolor,
						  onChange: buttontextcolor =>
							props.setAttributes({ buttontextcolor: buttontextcolor }),
						  label: __("Note Text Color")
						}
					  ]}
					/>
					<PanelColorSettings
							title={__("Text Color Settings")}
							initialOpen={false}
							colorSettings={[
						{
						  value: textcolor,
						  onChange: textcolor =>
							props.setAttributes({ textcolor: textcolor }),
						 label: __("Box Background Color")
						},
						{
						  value: boxcolor,
						  onChange: boxcolor =>
							props.setAttributes({ boxcolor: boxcolor }),
						  label: __("Box Background Color")
						}
					  ]}
					/>

					<PanelBody
						title="Set Icon"
						icon="category"
						initialOpen={false}
						className="iconSettingCus"
					>
							<Fragment>

								<RangeControl
									label={__('Enter Icon Size its in px')}
									value={customSizeIcon}
									min='10'
									max='50'
									step='1'
									onChange={function( customSizeIcon ) {
										props.setAttributes( { customSizeIcon: customSizeIcon } );
									}}
								/>
								<Fragment>

									<div className="material-icons-block">
										<MaterialUiIconPicker onPick={showPickedIcons} label="Choose Icon" pickLabel="Select" />
										<i className="material-icons">{iconName}</i>
									</div>

									<PanelColorSettings
										title={ __( 'Choose Icon Color ' ) }
										initialOpen={false}
										colorSettings={ [
											{
												value: iconColorCus,
												onChange: ( iconColorCusValue ) => props.setAttributes( { iconColorCus: iconColorCusValue } ),
												label: __( 'Select Color' ),
											},
										] }
									>
									</PanelColorSettings>

								</Fragment>

							</Fragment>
					</PanelBody>

				</InspectorControls>
				<BlockControls>
					<AlignmentToolbar
						value={align}
						onChange={textAlign => {
						setAttributes({ align: textAlign });
						}}
					/>
				</BlockControls>
			</Fragment>
		);
	},

	/**
	 * The save function defines the way in which the different attributes should be combined
	 * into the final markup, which is then serialized by Gutenberg into post_content.
	 *
	 * The "save" property must be specified and must be a valid function.
	 *
	 * @link https://wordpress.org/gutenberg/handbook/block-api/block-edit-save/
	 */
	save: function( props ) {

		const { attributes, setAttributes } = props;
		const {
			text,
			textcolor,
			buttontext,
			buttoncolor,
			buttontextcolor,
			boxcolor,
			align,
			customSizeIcon,
			iconColorCus,
			iconName,
			iconCode,
			customWidth,
			shortSep
		} = attributes;

		const onSelect = ( tabName ) => {};
		function emptymedia(){
			setAttributes({mediaURL:"",mediaID:""});
		}

		return (
			<div className={classnames('notification-block', {[`pos-${shortSep}`]: true} )} style={{

				}}>
				<div className="gosign-promobox" style={{
					...(customWidth ? {width : customWidth +"%" }:{}),
					...(iconColorCus ? {backgroundColor : boxcolor }:{})

					}}>

					<div className="gosign-promobox-button">
						<p style={{ backgroundColor: buttoncolor, color:buttontextcolor}}>
							{buttontext}
						</p>
					</div>

					<div className="gosign-promobox-textbox">
						<p style={{...(iconColorCus ? {color : textcolor }:{}) }}>
							<span className="iconD">
								<i className="material-icons" style={{
											...(iconColorCus ? {color : iconColorCus }:{}),
											...(customSizeIcon ? {fontSize : customSizeIcon +'px' }:{})
											}}>
									{iconName}
								</i>
							</span>
							<RichText.Content className={props.className} value={text} />
						</p>
					</div>

				</div>
				<div className="clear"></div>
			</div>
		);

	},
} );
